@@ -12,13 +12,30 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import datetime
 import unittest
 
+import mock
+
+
+def _create_signing_credentials():
+    import google.auth.credentials
+
+    class _SigningCredentials(
+            google.auth.credentials.Credentials,
+            google.auth.credentials.Signing):
+        pass
+
+    credentials = mock.Mock(spec=_SigningCredentials)
+
+    return credentials
+
 
 class Test_Bucket(unittest.TestCase):
 
     def _make_one(self, client=None, name=None, properties=None):
         from google.cloud.storage.bucket import Bucket
+
         if client is None:
             connection = _Connection()
             client = _Client(connection)
@@ -164,6 +181,7 @@ class Test_Bucket(unittest.TestCase):
 
     def test_acl_property(self):
         from google.cloud.storage.acl import BucketACL
+
         bucket = self._make_one()
         acl = bucket.acl
         self.assertIsInstance(acl, BucketACL)
@@ -171,6 +189,7 @@ class Test_Bucket(unittest.TestCase):
 
     def test_default_object_acl_property(self):
         from google.cloud.storage.acl import DefaultObjectACL
+
         bucket = self._make_one()
         acl = bucket.default_object_acl
         self.assertIsInstance(acl, DefaultObjectACL)
@@ -276,6 +295,7 @@ class Test_Bucket(unittest.TestCase):
 
     def test_delete_miss(self):
         from google.cloud.exceptions import NotFound
+
         NAME = 'name'
         connection = _Connection()
         client = _Client(connection)
@@ -369,6 +389,7 @@ class Test_Bucket(unittest.TestCase):
 
     def test_delete_blob_miss(self):
         from google.cloud.exceptions import NotFound
+
         NAME = 'name'
         NONESUCH = 'nonesuch'
         connection = _Connection()
@@ -413,6 +434,7 @@ class Test_Bucket(unittest.TestCase):
 
     def test_delete_blobs_miss_no_on_error(self):
         from google.cloud.exceptions import NotFound
+
         NAME = 'name'
         BLOB_NAME = 'blob-name'
         NONESUCH = 'nonesuch'
@@ -469,6 +491,7 @@ class Test_Bucket(unittest.TestCase):
 
     def test_copy_blobs_preserve_acl(self):
         from google.cloud.storage.acl import ObjectACL
+
         SOURCE = 'source'
         DEST = 'dest'
         BLOB_NAME = 'blob-name'
@@ -775,9 +798,9 @@ class Test_Bucket(unittest.TestCase):
         self.assertTrue('storageClass' in bucket._changes)
 
     def test_time_created(self):
-        import datetime
         from google.cloud._helpers import _RFC3339_MICROS
         from google.cloud._helpers import UTC
+
         TIMESTAMP = datetime.datetime(2014, 11, 5, 20, 34, 37, tzinfo=UTC)
         TIME_CREATED = TIMESTAMP.strftime(_RFC3339_MICROS)
         properties = {'timeCreated': TIME_CREATED}
@@ -832,6 +855,7 @@ class Test_Bucket(unittest.TestCase):
 
     def test_make_public_defaults(self):
         from google.cloud.storage.acl import _ACLEntity
+
         NAME = 'name'
         permissive = [{'entity': 'allUsers', 'role': _ACLEntity.READER_ROLE}]
         after = {'acl': permissive, 'defaultObjectAcl': []}
@@ -852,6 +876,7 @@ class Test_Bucket(unittest.TestCase):
 
     def _make_public_w_future_helper(self, default_object_acl_loaded=True):
         from google.cloud.storage.acl import _ACLEntity
+
         NAME = 'name'
         permissive = [{'entity': 'allUsers', 'role': _ACLEntity.READER_ROLE}]
         after1 = {'acl': permissive, 'defaultObjectAcl': []}
@@ -893,7 +918,6 @@ class Test_Bucket(unittest.TestCase):
         self._make_public_w_future_helper(default_object_acl_loaded=False)
 
     def test_make_public_recursive(self):
-        import mock
         from google.cloud.storage.acl import _ACLEntity
 
         _saved = []
@@ -1058,6 +1082,82 @@ class Test_Bucket(unittest.TestCase):
         self.assertEqual(page2.num_items, 0)
         self.assertEqual(iterator.prefixes, set(['foo', 'bar']))
 
+    def _test_generate_upload_policy_helper(self, **kwargs):
+        import base64
+        import json
+
+        credentials = _create_signing_credentials()
+        credentials.signer_email = mock.sentinel.signer_email
+        credentials.sign_bytes.return_value = b'DEADBEEF'
+        connection = _Connection()
+        connection.credentials = credentials
+        client = _Client(connection)
+        name = 'name'
+        bucket = self._make_one(client=client, name=name)
+
+        conditions = [
+            ['starts-with', '$key', '']]
+
+        policy_fields = bucket.generate_upload_policy(conditions, **kwargs)
+
+        self.assertEqual(policy_fields['bucket'], bucket.name)
+        self.assertEqual(
+            policy_fields['GoogleAccessId'], mock.sentinel.signer_email)
+        self.assertEqual(
+            policy_fields['signature'],
+            base64.b64encode(b'DEADBEEF').decode('utf-8'))
+
+        policy = json.loads(
+            base64.b64decode(policy_fields['policy']).decode('utf-8'))
+
+        policy_conditions = policy['conditions']
+        expected_conditions = [{'bucket': bucket.name}] + conditions
+        for expected_condition in expected_conditions:
+            for condition in policy_conditions:
+                if condition == expected_condition:
+                    break
+            else:  # pragma: NO COVER
+                self.fail('Condition {} not found in {}'.format(
+                    expected_condition, policy_conditions))
+
+        return policy_fields, policy
+
+    @mock.patch(
+        'google.cloud.storage.bucket._NOW',
+        return_value=datetime.datetime(1990, 1, 1))
+    def test_generate_upload_policy(self, now):
+        from google.cloud._helpers import _datetime_to_rfc3339
+
+        _, policy = self._test_generate_upload_policy_helper()
+
+        self.assertEqual(
+            policy['expiration'],
+            _datetime_to_rfc3339(
+                now() + datetime.timedelta(hours=1)))
+
+    def test_generate_upload_policy_args(self):
+        from google.cloud._helpers import _datetime_to_rfc3339
+
+        expiration = datetime.datetime(1990, 5, 29)
+
+        _, policy = self._test_generate_upload_policy_helper(
+            expiration=expiration)
+
+        self.assertEqual(
+            policy['expiration'],
+            _datetime_to_rfc3339(expiration))
+
+    def test_generate_upload_policy_bad_credentials(self):
+        credentials = object()
+        connection = _Connection()
+        connection.credentials = credentials
+        client = _Client(connection)
+        name = 'name'
+        bucket = self._make_one(client=client, name=name)
+
+        with self.assertRaises(AttributeError):
+            bucket.generate_upload_policy([])
+
 
 class _Connection(object):
     _delete_bucket = False
@@ -1066,6 +1166,7 @@ class _Connection(object):
         self._responses = responses
         self._requested = []
         self._deleted_buckets = []
+        self.credentials = None
 
     @staticmethod
     def _is_bucket_path(path):
@@ -1074,6 +1175,7 @@ class _Connection(object):
 
     def api_request(self, **kw):
         from google.cloud.exceptions import NotFound
+
         self._requested.append(kw)
 
         method = kw.get('method')
@@ -1087,7 +1189,7 @@ class _Connection(object):
 
         try:
             response, self._responses = self._responses[0], self._responses[1:]
-        except:
+        except IndexError:
             raise NotFound('miss')
         else:
             return response
@@ -1097,4 +1199,5 @@ class _Client(object):
 
     def __init__(self, connection, project=None):
         self._connection = connection
+        self._base_connection = connection
         self.project = project
